@@ -23,8 +23,7 @@ class TestGeneralCheck(unittest.TestCase):
         '''
         time_start = utils_lib.run_cmd(self, "date '+%T'", msg='retrive test system current time')
         self.log.info("Check no permission denied at nfs server - bug1655493")
-        cmd = 'sudo yum install -y nfs-utils'
-        utils_lib.run_cmd(self, cmd, msg='Install nfs-utils')
+        utils_lib.is_pkg_installed(self,pkg_name='nfs-utils')
         output = utils_lib.run_cmd(self, 'uname -r', expect_ret=0)
 
         if 'el7' in output or 'el6' in output:
@@ -58,9 +57,11 @@ class TestGeneralCheck(unittest.TestCase):
             expect_clocks = 'xen,tsc,hpet,acpi_pm'
         elif 'aarch64' in output:
             expect_clocks = 'arch_sys_counter'
-        elif 'AuthenticAMD' in output and 'KVM' in output:
+        elif 'Microsoft' in output:
+            expect_clocks = 'hyperv_clocksource_tsc_page,acpi_pm'
+        elif 'AuthenticAMD' in output and 'KVM' in output and not utils_lib.is_metal(self):
             expect_clocks = 'kvm-clock,tsc,acpi_pm'
-        elif 'GenuineIntel' in output and 'KVM' in output:
+        elif 'GenuineIntel' in output and 'KVM' in output and not utils_lib.is_metal(self):
             expect_clocks = 'kvm-clock,tsc,acpi_pm'
         else:
             expect_clocks = 'tsc,hpet,acpi_pm'
@@ -126,6 +127,36 @@ available_clocksource'
                     expect_not_kw='Unknown symbol',
                     msg='Check there is no Unknown symbol in dmesg')
 
+    def test_check_dmesg_nmi(self):
+        '''
+        case_name:
+            test_check_dmesg_nmi
+        case_priority:
+            1
+        component:
+            kernel
+        bugzilla_id:
+            1917824
+        customer_case_id:
+            02803548
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+           Check no "NMI received" before and after run 'perf top' in dmesg.
+        key_steps:
+            1.#dmesg
+            2.#timeout 20 perf top
+            3.#dmesg
+        expected_result:
+            There is no "NMI received" before and after run 'perf top' in dmesg.
+        '''
+        utils_lib.run_cmd(self, 'dmesg', expect_ret=0, expect_not_kw='NMI received', msg="Check there is no 'NMI received' in dmesg before run 'perf top'")
+        utils_lib.run_cmd(self, 'timeout --foreground 20 perf top ', msg="Run 'perf top' for 20s. ")
+        utils_lib.run_cmd(self, 'dmesg', expect_ret=0, expect_not_kw='NMI received', msg="Check there is no 'NMI received' in dmesg after run 'perf top'")
+
+
     def test_check_dmidecode_dump_segfault(self):
         '''
         case_name:
@@ -150,6 +181,8 @@ available_clocksource'
             No segmentation fault found.
         '''
         utils_lib.is_cmd_exist(self, cmd='dmidecode')
+        cmd = "sudo dmidecode --dump-bin {}/debug/dmidecode_debug.bin".format(self.log_dir)
+        utils_lib.run_cmd(self, cmd, msg='save dmidecode_debug.bin for debug purpose, please attach it if file bug')
         cmd = "sudo dmidecode --dump"
         utils_lib.run_cmd(self, cmd, expect_ret=0, expect_not_kw='Segmentation')
 
@@ -199,6 +232,50 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
 
         utils_lib.run_cmd(self, check_cmd, expect_ret=0, expect_not_kw='Vulnerable')
 
+    def test_check_cpuusage_exception(self):
+        '''
+        case_name:
+            test_check_cpuusage_exception
+        case_priority:
+            1
+        component:
+            kernel
+        bugzilla_id:
+            1956248
+        customer_case_id:
+            02929244
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Check if there is a process taking high usage of CPU abnormally.
+            If it shows the high usage of CPU abnormally(higher than 85% over 1min),the case fails.
+        key_steps:
+            1.#ps aux --sort=-%cpu|sed -n '2p'
+        expected_result:
+            The usage of CPU is normal(slower than 85% once in 1min).
+        '''
+        count=0
+        for i in range(60):
+            result_out = utils_lib.run_cmd(self, "ps aux --sort=-%cpu|sed -n '2p'", msg='Find process with highest usage of CPU')
+            result_out = result_out.split(' ')
+            while '' in result_out:
+                result_out.remove('')
+            if count == 0:
+                lastpid = int(result_out[1])
+            if float(result_out[2]) >= 85 and lastpid == int(result_out[1]):
+                lastpid = int(result_out[1])
+                count += 1
+                time.sleep(1)
+            else:
+                break
+        if count>=59:
+            command =''
+            for i in range(10, len(result_out)):
+                command += result_out[i] + ' '
+            self.fail(f'{command}(pid:{lastpid}) have abnormal usage of CPU.')
+
     def test_iostat_x(self):
         '''
         case_name:
@@ -265,12 +342,87 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         '''
         # redirect journalctl output to a file as it is not get return
         # normally in RHEL7
-        cmd = 'journalctl > /tmp/journalctl.log'
+        cmd = 'journalctl -b 0 > /tmp/journalctl.log'
         utils_lib.run_cmd(self, cmd, expect_ret=0)
         cmd = 'cat /tmp/journalctl.log'
         utils_lib.run_cmd(self, cmd, expect_ret=0, expect_not_kw='Traceback,Backtrace',
                         msg = "Check no Traceback,Backtrace in journal log")
 
+    def test_check_journalctl_cannot(self):
+        '''
+        case_name:
+            test_check_journalctl_cannot
+        case_priority:
+            2
+        component:
+            journal
+        bugzilla_id:
+            
+        customer_case_id:
+            
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check "journalctl |grep -i 'Could not'" reported and make sure there is 'Could not' log.
+        key_steps:
+            1.#journalctl |grep -i 'Could not'
+        expected_result:
+            No new unknown 'Could not' log found.
+        '''
+        utils_lib.check_log(self, 'Could not,can not', skip_words='test_check_journalctl_cannot', rmt_redirect_stdout=True)
+
+    def test_check_journalctl_conflict(self):
+        '''
+        case_name:
+            test_check_journalctl_conflict
+        case_priority:
+            2
+        component:
+            journal
+        bugzilla_id:
+            
+        customer_case_id:
+            
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check "journalctl |grep -i conflict" reported and make sure there is no conflict log.
+        key_steps:
+            1.#journalctl |grep -i conflict
+        expected_result:
+            No conflict log found.
+        '''
+        utils_lib.check_log(self, 'conflict', skip_words='test_check_journalctl_conflict', rmt_redirect_stdout=True)
+
+    def test_check_journalctl_denied(self):
+        '''
+        case_name:
+            test_check_journalctl_denied
+        case_priority:
+            2
+        component:
+            journal
+        bugzilla_id:
+            1978507
+        customer_case_id:
+            
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check "journalctl |grep -i denied" reported and make sure there is no unknown denied log.
+        key_steps:
+            1.#journalctl |grep -i denied
+        expected_result:
+            No new unknown denied log found.
+        '''
+        utils_lib.check_log(self, 'denied', skip_words='test_check_journalctl_denied', rmt_redirect_stdout=True)
+
     def test_check_journalctl_dumpedcore(self):
         '''
         polarion_id:
@@ -278,7 +430,7 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         '''
         # redirect journalctl output to a file as it is not get return
         # normally in RHEL7
-        cmd = 'journalctl > /tmp/journalctl.log'
+        cmd = 'journalctl -b 0 > /tmp/journalctl.log'
         utils_lib.run_cmd(self, cmd, expect_ret=0)
         cmd = 'cat /tmp/journalctl.log'
         utils_lib.run_cmd(self, cmd, expect_ret=0, expect_not_kw='dumped core',
@@ -287,40 +439,82 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         '''
         polarion_id: RHEL7-103851
         '''
-        utils_lib.check_log(self, 'error', skip_words='test_check', rmt_redirect_stdout=True)
+        utils_lib.check_log(self, 'error', skip_words='test_check,UpdateGSErrors', rmt_redirect_stdout=True)
 
     def test_check_journalctl_fail(self):
         '''
         case_name:
             test_check_journalctl_fail
-
         case_priority:
             1    
-
         component:
             kernel
-
         bugzilla_id:
             1879368
-
         polarion_id:
             RHEL7-103851
-
         maintainer:
             xiliang@redhat.com
-
         description:
-            Check "journalctl |grep -i fail" reported and make sure there is nounknown fail log.                     
-    
+            Check "journalctl |grep -i fail" reported and make sure there is nounknown fail log.
         key_steps:
             1.#journalctl |grep -i fail
-
         expected_result:
             No new unknown fail log found.
-
         '''
         utils_lib.check_log(self, 'fail', skip_words='test_check,nofail', rmt_redirect_stdout=True)
 
+    def test_check_journalctl_not_found(self):
+        '''
+        case_name:
+            test_check_journalctl_not_found
+        case_priority:
+            2
+        component:
+            journal
+        bugzilla_id:
+            1855252
+        customer_case_id:
+            
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check "journalctl |grep -i 'no such file'" reported and make sure there is file not found in log.
+        key_steps:
+            1.#journalctl |grep -i 'not found'
+            2.#journalctl |grep -i 'no such file'
+        expected_result:
+            No new unknown not file found log found.
+        '''
+        utils_lib.check_log(self, 'not found,no such', skip_words='test_check_journalctl_not_found', rmt_redirect_stdout=True)
+
+    def test_check_journalctl_unexpected(self):
+        '''
+        case_name:
+            test_check_journalctl_unexpected
+        case_priority:
+            2
+        component:
+            journal
+        bugzilla_id:
+            1978507
+        customer_case_id:
+            
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check "journalctl |grep -i unexpected" reported and make sure there is no unknown unexpected log.
+        key_steps:
+            1.#journalctl |grep -i unexpected
+        expected_result:
+            No new unknown unexpected log found.
+        '''
+        utils_lib.check_log(self, 'unexpected', skip_words='test_check_journalctl_unexpected', rmt_redirect_stdout=True)
+
     def test_check_journalctl_warn(self):
         '''
         polarion_id: RHEL7-103851
@@ -335,10 +529,32 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         utils_lib.check_log(self, 'invalid', skip_words="Invalid user,invalid user,test_check", rmt_redirect_stdout=True)
 
     def test_check_journalctl_service_unknown_lvalue(self):
-        '''
-        polarion_id:
-        bz:1871139
-        '''
+        """
+        case_name:
+            test_check_journalctl_service_unknown_lvalue
+        case_file:
+            https://github.com/liangxiao1/os-tests/blob/master/os_tests/tests/test_general_check.py
+        component:
+            systemd
+        bugzilla_id:
+            1871139
+        customer_case_id:
+            yes
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check service has no 'Unknown lvalue' in unit file
+        key_steps:
+            # systemd-analyze verify $service
+        expect_result:
+            # No 'Unknown lvalue' keywords in output
+        debug_want:
+            - service unit file content
+            - output from 'systemd-analyze verify $service'
+        """
+
         cmd = "systemctl list-unit-files |grep -v UNIT|grep -v listed|awk -F' ' '{print $1}'"
         all_services = utils_lib.run_cmd(self, cmd, msg='Get all systemd unit files').split('\n')
 
@@ -349,6 +565,40 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
             utils_lib.run_cmd(self, cmd)
             cmd = "journalctl --unit {}".format(service)
             utils_lib.check_log(self,'Unknown lvalue', log_cmd=cmd, rmt_redirect_stdout=True)
+            if not service or service.startswith('-'):
+                continue
+            cmd = "sudo systemd-analyze verify {}".format(service)
+            utils_lib.run_cmd(self, cmd, expect_not_kw='Unknown lvalue', msg='Check there is no Unknown lvalue in {}'.format(service))
+
+    def test_check_locale(self):
+        '''
+        case_name:
+            test_check_locale
+        case_file:
+            https://github.com/liangxiao1/os-tests/blob/master/os_tests/tests/test_general_check.py
+        case_priority:
+            1
+        component:
+            glibc
+        bugzilla_id:
+            2000878
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Check there are no errors on the output of 'locale'
+        key_steps:
+            1. # locale
+        expected_result:
+            No error information found.
+        debug_want:
+            1. # rpm -qa | grep glibc
+            2. # uname -r
+        '''
+        cmd = 'rpm -qa | grep glibc'
+        utils_lib.run_cmd(self, cmd, msg='please attach {} output if file bug'.format(cmd))
+        utils_lib.run_cmd(self, 'locale', expect_not_kw="Cannot", msg='check no errors about locale')
 
     def test_check_lshw_mem(self):
         '''
@@ -390,6 +640,54 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
 
         utils_lib.compare_nums(self, mem_in_gib, base_memory, ratio=15)
 
+    def test_check_lsmem_segfault(self):
+        '''
+        case_name:
+            test_check_lsmem_segfault
+        case_priority:
+            1
+        component:
+            util-linux
+        bugzilla_id:
+            1712768
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check there is no segmentation fault while running 'lsmem' and 'lsmem -o NODE'
+        key_steps:
+            # 1.lsmem
+            # 2.lsmem -o NODE
+        expected_result:
+            No segmentation fault found.
+        '''
+        utils_lib.run_cmd(self, 'lsmem', expect_ret=0, expect_not_kw='Segmentation', msg='check no segfault')
+        utils_lib.run_cmd(self, 'lsmem -o NODE', expect_ret=0, expect_not_kw='Segmentation', msg='check no segfault')
+
+    def test_check_lspci_invalid_domain(self):
+        '''
+        case_name:
+            test_check_lspci_invalid_domain
+        case_priority:
+            1
+        component:
+            kernel
+        bugzilla_id:
+            1551091
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check there is no 'Invalid domain' while running 'lspci'
+        key_steps:
+            # 1.lspci
+        expected_result:
+            'lspci' can list devices normally without "Invalid domain"
+        '''
+        utils_lib.run_cmd(self, 'lspci', expect_ret=0, expect_not_kw='Invalid', msg='check no invalid domain')
+
     def test_check_lspci_nvme(self):
         '''
         case_name:
@@ -468,6 +766,50 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
         if len(output) > 0:
             self.fail('Memory leak found!')
 
+    def test_check_memusage_exception(self):
+        '''
+        case_name:
+            test_check_memusage_exception
+        case_priority:
+            1
+        component:
+            kernel
+        bugzilla_id:
+            1956248
+        customer_case_id:
+            02929244
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Check if there is a process taking high usage of Memory abnormally.
+            If it shows the high usage of Memory abnormally(higher than 60% over 1min),the case fails.
+        key_steps:
+            1.#ps aux --sort=-rss|sed -n '2p'
+        expected_result:
+            The usage of Memory is normal(slower than 60% once in 1min).
+        '''
+        count=0
+        for i in range(60):
+            result_out = utils_lib.run_cmd(self, "ps aux --sort=-rss|sed -n '2p'", msg='Find process with highest usage of Memory')
+            result_out = result_out.split(' ')
+            while '' in result_out:
+                result_out.remove('')
+            if count == 0:
+                lastpid = int(result_out[1])
+            if float(result_out[3]) >= 60 and lastpid == int(result_out[1]):
+                lastpid = int(result_out[1])
+                count += 1
+                time.sleep(1)
+            else:
+                break
+        if count>=59:
+            command =''
+            for i in range(10, len(result_out)):
+                command += result_out[i] + ' '
+            self.fail(f'{command}(pid:{lastpid}) have abnormal usage of Memory.')
+
     def test_check_microcode_load(self):
         '''
         bz: 1607899
@@ -493,6 +835,52 @@ itlb_multihit|sed 's/:/^/' | column -t -s^"
                         expect_not_kw='microcode updated early',
                         msg='microcode should not load in VMs')
 
+    def test_check_nitro_enclaves(self):
+        '''
+        case_name:
+            test_check_nitro_enclaves
+        case_priority:
+            1
+        component:
+            kernel
+        bugzilla_id:
+            2011739
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Test whether nitro enclave is enabled.
+        key_steps:
+            1.#sudo yum -y install gcc make git podman-docker
+            2.#sudo setenforce 0
+            3.#git clone https://github.com/GAO567/aws-nitro-enclaves-cli.git
+            4.#cd aws-nitro-enclaves-cli; sudo make && sudo make vsock-proxy;sudo NITRO_CLI_INSTALL_DIR=/ make install-tools; cd ..
+            5.#sudo mkdir /run/nitro_enclaves/
+            6.#sudo systemctl enable nitro-enclaves-allocator.service && sudo systemctl start nitro-enclaves-allocator.service
+            7.#curl -O http://people.redhat.com/~vkuznets/hello_v2.eif
+            8.#sudo nitro-cli run-enclave --cpu-count 2 --memory 256 --eif-path hello_v2.eif --debug-mode
+            9.#nitro-cli describe-enclaves
+            10.#nitro-cli console --enclave-id $EnclaveID
+            11.#sudo nitro-cli terminate-enclave --enclave-id $EnclaveID
+        expected_result:
+            Enclave can be started and terminated successfully.
+        '''
+        if not utils_lib.is_aws(self):
+            self.skipTest('encalve is only for aws platform')
+        utils_lib.run_cmd(self, 'sudo yum -y install gcc make git podman-docker',timeout=300, msg='install required pkgs')
+        utils_lib.run_cmd(self, 'sudo setenforce 0', msg='disable SElinux')
+        utils_lib.run_cmd(self, 'git clone https://github.com/GAO567/aws-nitro-enclaves-cli.git', msg='clone nitro-enclaves-cli ')
+        utils_lib.run_cmd(self, 'cd aws-nitro-enclaves-cli; sudo make && sudo make vsock-proxy;sudo NITRO_CLI_INSTALL_DIR=/ make install-tools; cd ..', timeout=600,msg='make and install nitro-cli')
+        utils_lib.run_cmd(self, 'sudo mkdir /run/nitro_enclaves/')
+        utils_lib.run_cmd(self, 'sudo systemctl enable nitro-enclaves-allocator.service && sudo systemctl start nitro-enclaves-allocator.service')
+        utils_lib.run_cmd(self, 'curl -O http://people.redhat.com/~vkuznets/hello_v2.eif', msg='download test enclave')
+        utils_lib.run_cmd(self, 'sudo nitro-cli run-enclave --cpu-count 2 --memory 256 --eif-path hello_v2.eif --debug-mode', expect_kw='Started', msg='run enclave')
+        EnclaveID=utils_lib.run_cmd(self, 'nitro-cli describe-enclaves |grep EnclaveID', msg='get EnclaveID')
+        EnclaveID=EnclaveID[18:-3]
+        utils_lib.run_cmd(self, f'timeout 5 nitro-cli console --enclave-id {EnclaveID}', expect_kw='Successfully', msg='get the console')
+        utils_lib.run_cmd(self, f'sudo nitro-cli terminate-enclave --enclave-id {EnclaveID}', expect_kw='Successfully', msg='terminate enclave')
+
     def test_check_nouveau(self):
         '''
         polarion_id: N/A
@@ -649,6 +1037,31 @@ in cmdline as bug1859088")
         cmd = "find -H /sys -name cpu_list  -type f -perm -u=r -print -exec cat '{}' 2>&1 \;"
         utils_lib.run_cmd(self, cmd, msg='Check no crash seen when read cpu_list if exists')
 
+    def test_check_sys_modules_parameters_readable(self):
+        '''
+        case_name:
+            test_check_sys_modules_parameters_readable
+        case_priority:
+            1
+        component:
+            kernel
+        bugzilla_id:
+            1619602
+        customer_case_id:
+            02232284
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Check no panic happen when read all files under "/sys/module/*/parameters/".
+        key_steps:
+            1. # cat /sys/module/*/parameters/* 
+        expected_result:
+            No panic happen
+        '''
+        utils_lib.run_cmd(self, 'cat /sys/module/*/parameters/*', msg='Check no panic happen when read all files under "/sys/module/*/parameters/"')
+
     def test_check_systemd_analyze_verify_deprecated_unsafe(self):
         '''
         case_name:
@@ -683,6 +1096,43 @@ in cmdline as bug1859088")
             cmd = "sudo systemd-analyze verify {}".format(service)
             utils_lib.run_cmd(self, cmd, expect_not_kw='deprecated,unsafe', msg='Check there is no "deprecated" or "unsafe" keyword in output from {}'.format(service))
 
+    def test_check_systemd_analyze_verify_missing(self):
+        """
+        case_name:
+            test_check_systemd_analyze_verify_missing
+        case_file:
+            https://github.com/liangxiao1/os-tests/blob/master/os_tests/tests/test_general_check.py
+        component:
+            systemd
+        bugzilla_id:
+            2016305
+        customer_case_id:
+            N/A
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check service has no 'Missing' config in unit file
+        key_steps:
+            # systemd-analyze verify $service
+        expect_result:
+            # No 'Missing' keywords in output
+        debug_want:
+            - service unit file content
+            - output from 'systemd-analyze verify $service'
+        """
+        cmd = "sudo systemd-analyze verify default.target"
+        utils_lib.run_cmd(self, cmd, expect_not_kw='is obsolet', msg='Check there is no obsolet keyword in output')
+        cmd = "systemctl list-unit-files |grep -v UNIT|grep -v listed|awk -F' ' '{print $1}'"
+        all_services = utils_lib.run_cmd(self, cmd, msg='retrive all systemd unit files').split('\n')
+
+        for service in all_services:
+            if not service or service.startswith('-'):
+                continue
+            cmd = "sudo systemd-analyze verify {}".format(service)
+            utils_lib.run_cmd(self, cmd, expect_not_kw='Missing,ignoring line', msg='Check there is no Missing keyword in output from {}'.format(service))
+
     def test_check_systemd_analyze_verify_obsolete(self):
         '''
         case_name:
@@ -724,7 +1174,7 @@ in cmdline as bug1859088")
         polarion_id:
             n/a
         bugzilla_id: 
-            1932614
+            1932614, 1998445
         customer_case_id: 
             02878130
         maintainer: 
@@ -735,9 +1185,14 @@ in cmdline as bug1859088")
             systemd
         key_steps:
             # systemd-analyze verify default.target
+            # journalctl -b0 |grep -i 'Found ordering cycle'
         pass_criteria: 
             No ordering cycle found
+        debug_want:
+            # journalctl -b0
         '''
+        cmd = 'sudo journalctl -b0'
+        utils_lib.run_cmd(self, cmd, expect_not_kw='ordering cycle', msg='Check there is no ordering cycle in journal log')
         cmd = "sudo systemd-analyze verify default.target"
         utils_lib.run_cmd(self, cmd, expect_not_kw='ordering cycle', msg='Check there is no ordering cycle which may block boot up.')
         #cmd = "sudo systemctl list-units --type target|grep target|awk -F' ' '{print $1}'"
@@ -823,17 +1278,17 @@ current_device"
                 self.assertIn('xen-hvm', virt_what_output)
             else:
                 self.assertIn('xen-domU', virt_what_output)
-        elif 'KVM' in lscpu_output and not utils_lib.is_metal(self):
-            self.log.info("Found it is a kvm system!")
-            self.assertIn('kvm', virt_what_output)
+        elif 'Microsoft' in lscpu_output and not utils_lib.is_metal(self):
+            self.log.info("Found it is a Hyper-V system!")
+            self.assertIn('hyperv', virt_what_output)
         elif 'VMware' in lscpu_output:
             self.log.info("Found it is a vmware system!")
             self.assertIn('vmware', virt_what_output)
-        elif 'Microsoft' in lscpu_output:
-            self.log.info("Found it is a Hyper-V system!")
-            self.assertIn('hyperv', virt_what_output)
+        elif 'KVM' in lscpu_output and not utils_lib.is_metal(self):
+            self.log.info("Found it is a kvm system!")
+            self.assertIn('kvm', virt_what_output)
         elif utils_lib.is_metal(self) and utils_lib.is_aws(self):
-            self.log.info("Found it is a bare metal system!")
+            self.log.info("Found it is a aws bare metal system!")
             self.assertEqual('aws', virt_what_output.strip('\n'))
         elif utils_lib.is_metal(self):
             self.log.info("Found it is a bare metal system!")
@@ -842,6 +1297,63 @@ current_device"
         else:
             self.skipTest("Unknow hypervisor")
 
+    def test_check_rpm_V_differences(self):
+        '''
+        case_name:
+            test_check_rpm_V_differences
+        case_priority:
+            1
+        component:
+            rpm
+        bugzilla_id:
+            n/a
+        customer_case_id:
+            n/a
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check the pkg differences with information from database
+        key_steps:
+            1. # sudo rpm -qa
+            2. # sudo rpm -V $(pkg)
+        expected_result:
+            No pkg differences with information from database.
+        '''
+        character={'S': 'file Size differs',
+              'M': 'Mode differs (includes permissions and file type)',
+              '5':'digest (formerly MD5 sum) differs',
+              'D':'Device major/minor number mismatch',
+              'L':'readLink(2) path mismatch',
+              'U':'User ownership differs',
+              'G':'Group ownership differs',
+              'T':'mTime differs',
+              'P':'caPabilities differ',
+              '?':'test could not be performed'}
+        pkg=utils_lib.run_cmd(self, 'sudo rpm -qa', msg="list the pkgs")
+        pkg=pkg.split('\n')
+        count=0
+        differ=''
+        for i in range(len(pkg)-1):
+            out=utils_lib.run_cmd(self, f'sudo rpm -V {pkg[i]}', msg="check pkg differences")
+            if out != '':
+                out = out.split('\n')
+                if out[0][0] in '.S':
+                    count += 1
+                    differ += f'{count}.{pkg[i]}:\n'
+                    for j in out[:-1]:
+                        differ+=j+'\n'
+                        for k in j[0:9]:
+                            if k!='.':
+                                differ+=character[k]+'\n'
+        self.log.info("{}".format(differ))
+        allow_count = 25
+        if count>=allow_count:
+            self.fail("Too many ({}) differes found, please check.".format(count))
+        else:
+            self.log.info("Found few ({}) differs less than {}".format(count,allow_count))
+
     def test_check_rpm_V_efi(self):
         '''
         bz: 1845052
@@ -853,6 +1365,43 @@ current_device"
         cmd = "sudo rpm -V efi-filesystem"
         utils_lib.run_cmd(self, cmd, expect_ret=0, msg="check rpm verify status")
 
+    def test_check_rpm_V_missing(self):
+        '''
+        case_name:
+            test_check_rpm_V_missing
+        case_priority:
+            1
+        component:
+            rpm
+        bugzilla_id:
+            n/a
+        customer_case_id:
+            n/a
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            check pkg missing file problem
+        key_steps:
+            1. # sudo rpm -qa
+            2. # sudo rpm -V $(pkg)
+        expected_result:
+            No missing file found in output.
+        '''
+        skip = ['rhui']
+        pkg = utils_lib.run_cmd(self, 'sudo rpm -qa', msg="list the pkgs")
+        pkg = pkg.split('\n')
+        for i in range(len(pkg) - 1):
+            status = 0
+            for j in skip:
+                if re.search(j, pkg[i]):
+                    status += 1
+                else:
+                    pass
+            if status == 0:
+                utils_lib.run_cmd(self, f'sudo rpm -V {pkg[i]}', expect_not_kw="missing", msg="check pkg missing problem")
+
     def test_collect_insights_result(self):
         '''
         case_name:
@@ -907,7 +1456,7 @@ current_device"
         out = utils_lib.run_cmd(self,
                 'sudo insights-client --no-upload --keep-archive',
                 expect_ret=0, expect_kw="tar.gz",
-                msg="generate archive", timeout=180)
+                msg="please attach this archive if file bug", timeout=180)
         gz_file = re.findall('/var/.*tar.gz', out)[0]
         file_name = gz_file.split('/')[-1]
         utils_lib.run_cmd(self, 'sudo cp {} {}'.format(gz_file, self.log_dir))
