@@ -1,7 +1,9 @@
 import unittest
 import re
+import os_tests
 from os_tests.libs import utils_lib
 import time
+import os
 
 class TestGeneralTest(unittest.TestCase):
     def setUp(self):
@@ -68,11 +70,39 @@ current_clocksource'
 
     def test_cpupower_exception(self):
         '''
-        No exception when run cpupower command
-        polarion_id: N/A
-        bz: 1626505, 1659883
+        case_name:
+            test_cpupower_exception
+        case_file:
+            https://github.com/liangxiao1/os-tests/blob/master/os_tests/tests/test_general_test.py
+        case_priority:
+            2
+        component:
+            kernel-Platform Enablement
+        bugzilla_id:
+            1626505, 1659883, 1999926
+        customer_case_id:
+            02172487
+        polarion_id:
+            n/a
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Run cpupower to query processor power related values. It may not support all fields, but crash is not expected.
+        key_steps:
+            1. # cpupower info
+            2. # cpupower idle-info
+            3. # cpupower frequency-info
+        expected_result:
+            No application crash when run cpupower command, all return 0.
+        debug_want:
+            1. # lscpu
+            2. # rpm -q kernel-tools
+            3. # uname -r
         '''
         utils_lib.is_cmd_exist(self, 'cpupower')
+        debug_cmds = ['lscpu', 'rpm -q kernel-tools', 'uname -r']
+        for cmd in debug_cmds:
+            utils_lib.run_cmd(self, cmd, msg='please attach {} output if file bug'.format(cmd))
         cmd = "sudo cpupower info"
         utils_lib.run_cmd(self, cmd, expect_ret=0, expect_not_kw='core dumped')
         cmd = "sudo cpupower idle-info"
@@ -147,7 +177,7 @@ current_clocksource'
             FIPS_selftest() pass
         key_steps:
             1. # gcc fipstest.c -o fipstest -lcrypto
-            2. # # ./fipstest
+            2. # ./fipstest
         expected_result:
             No fips selftest failed.
         '''
@@ -232,10 +262,18 @@ int main(int argc, char *argv[])
             self.skipTest('skip when mem lower than 4GiB')
         utils_lib.is_cmd_exist(self, cmd='gcc', cancel_case=True)
         utils_lib.is_cmd_exist(self, cmd='wget', cancel_case=True)
-        cmd_list = ['wget https://github.com/redis/redis/files/5717040/redis_8124.c.txt',
-                    'mv redis_8124.c.txt redis_8124.c',
-                    'gcc -o reproduce redis_8124.c',
-                    'sudo systemd-run --scope -p MemoryLimit=550M ./reproduce']
+        utils_dir = os.path.realpath(os_tests.__file__)
+        utils_dir = os.path.dirname(utils_dir) + '/utils'
+        redis_src = utils_dir + '/redis_8124.c'
+        redis_src_tmp = '/tmp/redis_8124.c'
+        if self.params['remote_node'] is not None:
+            self.log.info('Copy {} to remote'.format(redis_src))
+            self.SSH.put_file(local_file=redis_src, rmt_file=redis_src_tmp)
+        else:
+            cmd = "sudo cp -f {} {}".format(redis_src, redis_src_tmp)
+            utils_lib.run_cmd(self, cmd, expect_ret=0, timeout=120)
+        cmd_list = ['gcc -o /tmp/reproduce /tmp/redis_8124.c',
+                    'sudo systemd-run --scope -p MemoryLimit=550M /tmp/reproduce']
         for cmd in cmd_list:
             out = utils_lib.run_cmd(self, cmd, expect_ret=0, timeout=120)
         if 'Your kernel looks fine' not in out:
@@ -259,13 +297,12 @@ int main(int argc, char *argv[])
         '''
         bz: 1932802, 1905398
         '''
-        cmd = "sudo rpm -qa|grep rhui"
-        utils_lib.run_cmd(self, cmd, cancel_ret='0', msg='skip test if rhui is not installed')
+        if not (utils_lib.is_aws(self) or utils_lib.is_azure(self)):
+            self.skipTest('Auto registeration only supports AWS and Azure platforms for now.')
 
         product_id = utils_lib.get_product_id(self)
         if float(product_id) < 8.4:
             self.skipTest('skip in earlier than el8.4')
-        self.log.info("Auto registeration only supports AWS and Azure platforms for now.")
 
         cmd = "sudo subscription-manager config --rhsmcertd.auto_registration=1 --rhsm.manage_repos=0 --rhsmcertd.auto_registration_interval=1"
         utils_lib.run_cmd(self, cmd, expect_ret=0, msg='try to enable auto_registration, disable managed_repos and change inverval from 60mins to 1min')
@@ -558,6 +595,11 @@ grep -i pci|grep n1' % boot_pci
             self,
             'sudo virsh nodedev-list|grep %s |tail -1' % tmp_pci,
             msg='pick up device to detach')
+        pci_dev_1 = re.findall('pci_.*',pci_dev_1)
+        if len(pci_dev_1) > 0:
+            pci_dev_1= pci_dev_1[0]
+        else:
+            self.fail("no {} found in output".format(tmp_pci))
         if pci_dev_1.endswith('1'):
             pci_dev_0 = pci_dev_1.rstrip('1') + '0'
             utils_lib.run_cmd(self,
