@@ -207,30 +207,27 @@ class TestNetworkTest(unittest.TestCase):
         '''
         case_name:
             test_ethtool_S_xdp
-
+        case_file:
+            https://github.com/liangxiao1/os-tests/blob/master/os_tests/tests/test_network_test.py
         case_priority:
             2
-
         component:
             kernel
-
         bugzilla_id:
-            1908542
-
+            1908542, 2000400
         polarion_id:
             n/a
-
         maintainer:
             xiliang@redhat.com
-
         description:
             Use ethtool to query the specified network device xdp statistics.
-
         key_steps:
             1. # ethtool -S $nic |grep xdp
-
+            2. # xdp-loader status (xdp-tools is required and it is only support x86_64 for now)
+            3. # xdp-loader unload -a
+            4. # xdp-filter load --mode skb $nic
         expected_result:
-            xdp status found
+            1. xdp data found
             eg. # ethtool -S eth0 |grep xdp
                   queue_0_rx_xdp_aborted: 0
                   queue_0_rx_xdp_drop: 0
@@ -238,6 +235,12 @@ class TestNetworkTest(unittest.TestCase):
                   queue_0_rx_xdp_tx: 0
                   queue_0_rx_xdp_invalid: 0
                   queue_0_rx_xdp_redirect: 0
+            2. xdp-loader works on x86_64 platform
+        debug_want:
+            1. # uname -r
+            2. # ethtool -i $nic
+            3. # rpm -q xdp-tools (if fail at xdp-tools)
+            4. # xdp-loader $cmd -vv
 
         '''
         product_id = utils_lib.get_product_id(self)
@@ -255,6 +258,7 @@ class TestNetworkTest(unittest.TestCase):
             utils_lib.run_cmd(self, cmd, cancel_ret='0', msg='Check if have xdp support')
         if float(product_id) > 8.3 and utils_lib.is_arch(self, arch='x86_64'):
             utils_lib.is_cmd_exist(self, 'xdp-loader')
+            self.log.info('please attach debug log with -vv appended when report xdp-tools issue')
             cmd = 'sudo xdp-loader status'
             utils_lib.run_cmd(self, cmd, expect_ret=0,msg='Check xdp-loader status')
             cmd = 'sudo xdp-loader unload -a {}'.format(self.nic)
@@ -324,6 +328,11 @@ class TestNetworkTest(unittest.TestCase):
             mtu_range = [0, 67, 68, 1500,1600]
             mtu_min = 68
             mtu_max = 1500
+        elif 'hv_netvsc' in output:
+            self.log.info('hv_netvsc found, linux/drivers/net/hyperv/netvsc_drv.c  MTU range: 68 - 1500 or 65521')
+            mtu_range = [0, 67, 68, 4500, 65521, 65525]
+            mtu_min = 68
+            mtu_max = 65521
         else:
             self.log.info('Did not detect network type, use default min~max mtu. %s' % output)
             mtu_range = [0, 67, 68, 4500, 65535, 65536]
@@ -381,11 +390,72 @@ class TestNetworkTest(unittest.TestCase):
         con_name = con_name.lstrip(' ')
         cmd = "sudo nmcli connection modify '{}' +ipv4.routes '10.8.8.0/24 {}'".format(con_name, self.ipv4)
         utils_lib.run_cmd(self, cmd, expect_ret=0, msg='try to add static route name')
+        utils_lib.run_cmd(self, 'ip r', msg='print route after added')
         cmd = "sudo bash -c 'nmcli connection down \"{con}\";nmcli connection up \"{con}\"'".format(con=con_name)
         utils_lib.run_cmd(self, cmd, msg='down and up the connection')
         time.sleep(10)
         cmd = 'ip r'
-        utils_lib.run_cmd(self, cmd, expect_kw='10.8.8.0', msg='check new route added')
+        utils_lib.run_cmd(self, cmd, expect_kw='10.8.8.0', msg='check new route again after down and up connection')
+
+    def test_route_interfere(self):
+        """
+        case_name:
+            test_route_interfere
+        case_file:
+            https://github.com/liangxiao1/os-tests/blob/master/os_tests/tests/test_network_test.py
+        component:
+            NetworkManager
+        bugzilla_id:
+            1977984
+        customer_case_id:
+            02984023
+        testplan:
+            N/A
+        maintainer:
+            xiliang@redhat.com
+        description:
+            Check the route working if system has other IP that have routes in the "main" table.
+        key_steps:
+            # mkdir -p /tmp/test
+            # echo 'hello new site!' > /tmp/test/hello
+            # podman run -dit --name httpd_site -p 8188:80 -v "/tmp/test":/usr/local/apache2/htdocs/ httpd:2.4
+            # systemctl restart nm-cloud-setup (if enabled)
+            # curl http://$serverip:8188/hello (with NetworkManager-cloud-setup installed, curl failed, without nm-cloud, curl ok)
+        expect_result:
+            - curl return "hello new site"
+        debug_want:
+            # ip -4 route show table all
+        """
+        is_cloud_setup_installed = False
+        if utils_lib.is_pkg_installed(self, pkg_name='NetworkManager-cloud-setup', is_install=False):
+            cmd = 'sudo systemctl status nm-cloud-setup.timer'
+            utils_lib.run_cmd(self, cmd, msg='get nm-cloud-setup.timer status')
+            is_cloud_setup_installed = True
+        cmd = "podman rm -a -f"
+        utils_lib.run_cmd(self, cmd, msg='try to clean all containers before testing')
+        cmd = 'sudo ip -4 route show table all|sort'
+        utils_lib.run_cmd(self, cmd, msg='get ip routes')
+        cmd = 'sudo mkdir -p /tmp/test'
+        utils_lib.run_cmd(self, cmd, msg='create /tmp/test')
+        cmd = "sudo echo 'hello new site!' > /tmp/test/hello"
+        utils_lib.run_cmd(self, cmd, msg='create /tmp/test/hello')
+        registries = ['docker.io/library/httpd:2.4','docker.mirrors.ustc.edu.cn/library/httpd:2.4']
+        for registry in registries:
+            cmd = 'sudo podman run -dit --name httpd_site -p 8188:80 -v "/tmp/test":/usr/local/apache2/htdocs/ {}'.format(registry)
+            ret = utils_lib.run_cmd(self, cmd, timeout=600, msg='start container httpd_site', ret_status=True)
+            if ret == 0:
+                break
+            cmd = "podman rm -a -f"
+            utils_lib.run_cmd(self, cmd, msg='try to clean all containers before testing')
+        cmd = "podman ps -a"
+        utils_lib.run_cmd(self, cmd, msg='list all running containers')
+        if is_cloud_setup_installed:
+            cmd = 'sudo systemctl restart nm-cloud-setup'
+            utils_lib.run_cmd(self, cmd, msg='restart nm-cloud-setup')
+        cmd = 'sudo ip -4 route show table all|sort'
+        utils_lib.run_cmd(self, cmd, msg='get ip routes')
+        cmd = "curl --connect-timeout 5 http://{}:8188/hello".format(self.ipv4)
+        utils_lib.run_cmd(self, cmd, expect_kw='new site', msg='test site is available')
 
     def tearDown(self):
         if 'test_mtu_min_max_set' in self.id():
